import 'package:flutter/material.dart';
import 'package:syncrow_web/utils/color_manager.dart';

class AccurateDialogWidget extends StatelessWidget {
  final String title;
  final Widget body;
  final void Function() leftOnTap;
  final void Function() rightOnTap;
  const AccurateDialogWidget({
    super.key,
    required this.title,
    required this.body,
    required this.leftOnTap,
    required this.rightOnTap,
  });

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: 300,
      width: 400,
      child: Column(
        children: [
          Padding(
            padding: const EdgeInsets.all(10),
            child: Text(
              title,
              style: const TextStyle(
                fontSize: 24,
                fontWeight: FontWeight.bold,
                color: ColorsManager.blueColor,
              ),
            ),
          ),
          const SizedBox(height: 5),
          const Divider(
            indent: 10,
            endIndent: 10,
          ),
          Padding(
            padding: const EdgeInsets.all(10),
            child: body,
          ),
          const SizedBox(height: 20),
          const Spacer(),
          const Divider(),
          Row(
            children: [
              Expanded(
                child: InkWell(
                  onTap: leftOnTap,
                  child: Container(
                    height: 60,
                    alignment: Alignment.center,
                    decoration: const BoxDecoration(
                      border: Border(
                        right: BorderSide(
                          color: ColorsManager.grayBorder,
                        ),
                      ),
                    ),
                    child: const Text(
                      'Cancel',
                      style: TextStyle(color: ColorsManager.grayBorder),
                    ),
                  ),
                ),
              ),
              Expanded(
                child: InkWell(
                  onTap: rightOnTap,
                  child: Container(
                    height: 60,
                    alignment: Alignment.center,
                    decoration: const BoxDecoration(
                      border: Border(
                        right: BorderSide(
                          color: ColorsManager.grayBorder,
                        ),
                      ),
                    ),
                    child: const Text(
                      'Next',
                      style: TextStyle(
                        color: ColorsManager.blueColor,
                      ),
                    ),
                  ),
                ),
              )
            ],
          )
        ],
      ),
    );
  }
}
